View source: R/4_2Indexes_size_missing.R
| Indexes_size_missing_multi | R Documentation |
Stores the position of the begining of each gap and their respective size within a multivariate signal.
Indexes_size_missing_multi(data)
data |
multivariate signal |
A list with one element per signal. Within each element of this list, the first column gives the position of the begining of each gap and the second column its size.
data(dataDTWUMI)
id_NA <- Indexes_size_missing_multi(dataDTWUMI$incomplete_signal)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.