dataDTWUMI: A multivariate times series consisting of three signals as example for DTWUMI package
Description
A multivariate times series consisting of three signals as example for DTWUMI package
Usage
dataDTWUMI
Arguments
Format
A list storing two data frames with three columns each.
The first table contains the original complete simulated data.
The second table contains the same simulated data with one large gap added within each signal.