dot-dist_afbdtw_matrix: Adaptive Feature Based Dynamic Time Warping algorithm for...

.dist_afbdtw_matrixR Documentation

Adaptive Feature Based Dynamic Time Warping algorithm for multivariate signals

Description

This function estimates a distance matrix which is used as an input in dtw() function (package dtw) to align two multivariate signals following Adaptative Feature Based Dynamic Time Warping algorithm (AFBDTW).

Usage

.dist_afbdtw_matrix(q, r, w1 = 0.5)

Arguments

q

query dataframe

r

reference dataframe

w1

weight of local feature VS global feature. By default, w1 = 0.5, and by definition, w2 = 1 - w1.

Value

A distance matrix between the observations of q and r, combining local and global feature-based distances. The two distances are weighted by w1 and w2 = 1 - w1, respectively.


DTWUMI documentation built on Sept. 9, 2026, 9:08 a.m.