dot-features_matrix: Feature matrix

.features_matrixR Documentation

Feature matrix

Description

Store global features of a multivariate signal within a feature matrix. Values for each signal (column of the dataset storing the multivariate signal) are concatenated.

Usage

.features_matrix(data)

Arguments

data

multivariate signal

Value

A matrix with one row, where each column contains the value of corresponding estimated feature:

minx

Minimum value of the input vector.

maxx

Maximum value of the input vector.

avg

Mean value of the input vector.

medianx

Median value of the input vector.

std

Standard deviation of the input vector.

momx

Skewness of the input vector.

nop

Number of peaks in the input vector.

len

Length of the input vector.

entro

Entropy of the input vector.

Examples

data(dataDTWUMI)
gf <- .features_matrix(dataDTWUMI$full_signal)

DTWUMI documentation built on Sept. 9, 2026, 9:08 a.m.