View source: R/4_3_1Imputing_1NA.R
| imp_1NA | R Documentation |
Imputes isolated missing values based on the average of nearest neighbours.
imp_1NA(data, pos1)
data |
a univariate signal |
pos1 |
the position of the begining of gaps of size 1, as obtained using Indexes_size_missing_multi() function |
A new vector of the same size with imputed values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.