| .dist_afbdtw_matrix | R Documentation |
This function estimates a distance matrix which is used as an input in dtw() function (package dtw) to align two multivariate signals following Adaptative Feature Based Dynamic Time Warping algorithm (AFBDTW).
.dist_afbdtw_matrix(q, r, w1 = 0.5)
q |
query dataframe |
r |
reference dataframe |
w1 |
weight of local feature VS global feature. By default, w1 = 0.5, and by definition, w2 = 1 - w1. |
A distance matrix between the observations of q and r, combining local and global feature-based distances. The two distances are weighted by w1 and w2 = 1 - w1, respectively.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.