Learn R Programming

DTWUMI (version 1.0)

imp_1NA: Imputing gaps of size 1

Description

Imputes isolated missing values based on the average of nearest neighbours.

Usage

imp_1NA(data, pos1)

Arguments

data

a univariate signal

pos1

the position of the begining of gaps of size 1, as obtained using Indexes_size_missing_multi() function

Value

returns a new vector of same size with imputed values