powered by
Imputes isolated missing values based on the average of nearest neighbours.
imp_1NA(data, pos1)
a univariate signal
the position of the begining of gaps of size 1, as obtained using Indexes_size_missing_multi() function
returns a new vector of same size with imputed values